export const initializeSession = async ({ baseUrl, body, headers, }) => {
    var _a;
    const url = new URL(`${baseUrl}/widgets/session/initialize`);
    const localHeaders = new Headers(headers);
    localHeaders.append('Content-Type', 'application/json');
    const options = {
        method: 'POST',
        body: JSON.stringify(body),
        headers: localHeaders,
    };
    try {
        const res = await fetch(url.href, options);
        const data = await res.json();
        const newToken = (_a = data === null || data === void 0 ? void 0 : data.data) === null || _a === void 0 ? void 0 : _a.token;
        headers.append('Widget-Authorization', `Bearer ${newToken}`);
        const unseenCounter = await getUnseenCount({
            baseUrl,
            headers,
        });
        return {
            token: newToken,
            unseenCounter,
        };
    }
    catch (error) {
        console.log(error);
        return {
            token: null,
            unseenCounter: 0,
        };
    }
};
export const getUnseenCount = async ({ baseUrl, headers, }) => {
    var _a;
    const url = new URL(`${baseUrl}/widgets/notifications/unseen?limit=100`);
    const options = {
        method: 'GET',
        headers,
    };
    try {
        const res = await fetch(url.href, options);
        const data = await res.json();
        const unseenCount = ((_a = data === null || data === void 0 ? void 0 : data.data) === null || _a === void 0 ? void 0 : _a.count) || 0;
        return unseenCount;
    }
    catch (error) {
        console.log(error);
        return 0;
    }
};
export const deleteMessage = async ({ baseUrl, headers, messageId, }) => {
    const url = new URL(`${baseUrl}/widgets/messages/${messageId}`);
    const options = {
        method: 'DELETE',
        headers,
    };
    try {
        await fetch(url.href, options);
        return false;
    }
    catch (error) {
        console.log(error);
        return true;
    }
};
export const markAsRead = async ({ baseUrl, body, headers, unread, }) => {
    const url = new URL(`${baseUrl}/widgets/messages/markAs`);
    const localHeaders = new Headers(headers);
    localHeaders.append('Content-Type', 'application/json');
    const options = {
        method: 'POST',
        headers: localHeaders,
        body: JSON.stringify(body),
    };
    try {
        const res = await fetch(url.href, options);
        const data = await res.json();
        return {
            messageSeen: data.data[0].seen,
            messageRead: data.data[0].read,
            showSettingsModal: false,
        };
    }
    catch (err) {
        console.error('err', err);
        return {
            messageSeen: unread,
            messageRead: unread,
            showSettingsModal: true,
        };
    }
};
export const getNotifications = async ({ baseUrl, headers, page, }) => {
    const url = new URL(`${baseUrl}/widgets/notifications/feed`);
    url.searchParams.append('page', page.toString());
    const options = {
        method: 'GET',
        headers,
    };
    try {
        const res = await fetch(url.href, options);
        const data = await res.json();
        return {
            isLoading: false,
            numberOfNotifications: data.totalCount,
            notifications: data.data,
        };
    }
    catch (error) {
        console.log(error);
        return {
            isLoading: false,
            numberOfNotifications: 0,
            notifications: [],
        };
    }
};
export const markAllAsRead = async ({ baseUrl, headers, }) => {
    const url = new URL(`${baseUrl}/widgets/messages/read`);
    const localHeaders = new Headers(headers);
    localHeaders.append('Content-Type', 'application/json');
    const options = {
        method: 'POST',
        body: JSON.stringify({}),
        headers: localHeaders,
    };
    try {
        await fetch(url.href, options);
        return true;
    }
    catch (error) {
        console.log(error);
        return false;
    }
};
